@@ -170,11 +170,8 @@ static GtkTreePath *
 brasero_track_data_cfg_node_to_path (BraseroTrackDataCfg *self,
 				     BraseroFileNode *node)
 {
-	BraseroTrackDataCfgPrivate *priv;
 	GtkTreePath *path;
 
-	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (self);
-
 	path = gtk_tree_path_new ();
 	for (; node->parent && !node->is_root; node = node->parent) {
 		guint nth;
@@ -597,15 +594,13 @@ brasero_track_data_cfg_node_hidden (GtkTreeModel *model,
 
 static void
 brasero_track_data_cfg_get_value (GtkTreeModel *model,
-				   GtkTreeIter *iter,
-				   gint column,
-				   GValue *value)
+				  GtkTreeIter *iter,
+				  gint column,
+				  GValue *value)
 {
 	BraseroTrackDataCfgPrivate *priv;
-	BraseroTrackDataCfg *self;
 	BraseroFileNode *node;
 
-	self = BRASERO_TRACK_DATA_CFG (model);
 	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (model);
 
 	/* make sure that iter comes from us */
@@ -1120,10 +1115,10 @@ brasero_track_data_cfg_drag_data_received (GtkTreeDragDest *drag_dest,
 					   GtkTreePath *dest_path,
 					   GtkSelectionData *selection_data)
 {
+	GdkAtom target;
 	BraseroFileNode *node;
 	BraseroFileNode *parent;
 	GtkTreePath *dest_parent;
-	GdkAtom target;
 	BraseroTrackDataCfgPrivate *priv;
 
 	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (drag_dest);
@@ -1175,11 +1170,9 @@ brasero_track_data_cfg_drag_data_received (GtkTreeDragDest *drag_dest,
 	else if (target == gdk_atom_intern ("text/uri-list", TRUE)) {
 		gint i;
 		gchar **uris;
-		gboolean success = FALSE;
 
 		/* NOTE: there can be many URIs at the same time. One
 		 * success is enough to return TRUE. */
-		success = FALSE;
 		uris = gtk_selection_data_get_uris (selection_data);
 		if (!uris) {
 			const guchar *selection_data_raw;
@@ -1192,14 +1185,10 @@ brasero_track_data_cfg_drag_data_received (GtkTreeDragDest *drag_dest,
 			return TRUE;
 
 		for (i = 0; uris [i]; i ++) {
-			BraseroFileNode *node;
-
 			/* Add the URIs to the project */
-			node = brasero_data_project_add_loading_node (BRASERO_DATA_PROJECT (priv->tree),
-								      uris [i],
-								      parent);
-			if (node)
-				success = TRUE;
+			brasero_data_project_add_loading_node (BRASERO_DATA_PROJECT (priv->tree),
+			                                       uris [i],
+			                                       parent);
 		}
 		g_strfreev (uris);
 	}
@@ -2397,10 +2386,6 @@ static BraseroBurnResult
 brasero_track_data_cfg_get_track_type (BraseroTrack *track,
 				       BraseroTrackType *type)
 {
-	BraseroTrackDataCfgPrivate *priv;
-
-	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (track);
-
 	brasero_track_type_set_has_data (type);
 	brasero_track_type_set_data_fs (type, brasero_track_data_cfg_get_fs (BRASERO_TRACK_DATA (track)));
 
@@ -3412,59 +3397,12 @@ brasero_track_data_cfg_finalize (GObject *object)
 		 * so we better remove all signals.
 		 * When an image URI is detected it can happen
 		 * that we'll be destroyed. */
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_node_added,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_node_changed,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_node_removed,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_node_reordered,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_size_changed_cb,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_session_available_cb,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_session_loaded_cb,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_project_loaded,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_activity_changed,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_deep_directory,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_2G_file,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_unreadable_uri_cb,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_unknown_uri_cb,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_recursive_uri_cb,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_image_uri_cb,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_virtual_sibling_cb,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_name_collision_cb,
-		                                      object);
-		g_signal_handlers_disconnect_by_func (priv->tree,
-		                                      brasero_track_data_cfg_joliet_rename_cb,
+		g_signal_handlers_disconnect_matched (priv->tree,
+		                                      G_SIGNAL_MATCH_DATA,
+		                                      0,
+		                                      0,
+		                                      NULL,
+		                                      NULL,
 		                                      object);
 
 		g_object_unref (priv->tree);
