@@ -295,7 +295,7 @@ brasero_project_get_type ()
 			NULL
 		};
 
-		type = g_type_register_static (GTK_TYPE_VBOX, 
+		type = g_type_register_static (GTK_TYPE_BOX, 
 					       "BraseroProject",
 					       &our_info, 0);
 
@@ -588,18 +588,24 @@ brasero_utils_disc_style_changed_cb (GtkWidget *widget,
 				     GtkStyle *previous,
 				     GtkWidget *event_box)
 {
+	GdkRGBA color;
+
 	/* The widget (a treeview here) needs to be realized to get proper style */
 	gtk_widget_realize (widget);
-	gtk_widget_modify_bg (event_box, GTK_STATE_NORMAL, &gtk_widget_get_style (widget)->base[GTK_STATE_NORMAL]);
+	gdk_rgba_parse (&color, "white");
+	gtk_widget_override_background_color (event_box, GTK_STATE_NORMAL, &color);
 }
 
 static void
 brasero_utils_disc_realized_cb (GtkWidget *event_box,
 				GtkWidget *textview)
 {
+	GdkRGBA color;
+
 	/* The widget (a treeview here) needs to be realized to get proper style */
 	gtk_widget_realize (textview);
-	gtk_widget_modify_bg (event_box, GTK_STATE_NORMAL, &gtk_widget_get_style (textview)->base[GTK_STATE_NORMAL]);
+	gdk_rgba_parse (&color, "white");
+	gtk_widget_override_background_color (event_box, GTK_STATE_NORMAL, &color);
 
 	g_signal_handlers_disconnect_by_func (textview,
 					      brasero_utils_disc_style_changed_cb,
@@ -889,7 +895,7 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 		||  brasero_status_get_result (status) == BRASERO_BURN_RUNNING) {
 			cursor = gdk_cursor_new (GDK_WATCH);
 			gdk_window_set_cursor (window, cursor);
-			gdk_cursor_unref (cursor);
+			g_object_unref (cursor);
 		}
 		else
 			gdk_window_set_cursor (window, NULL);
@@ -1038,6 +1044,8 @@ brasero_project_init (BraseroProject *obj)
 
 	obj->priv = g_new0 (BraseroProjectPrivate, 1);
 
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (obj), GTK_ORIENTATION_VERTICAL);
+
 	g_signal_connect (G_OBJECT (obj),
 			  "set-focus-child",
 			  G_CALLBACK (brasero_project_focus_changed_cb),
@@ -1318,7 +1326,7 @@ brasero_project_install_missing (BraseroPluginErrorType type,
 
 	/* Get the xid */
 	parent = gtk_widget_get_toplevel (GTK_WIDGET (project));
-	xid = gdk_x11_drawable_get_xid (GDK_DRAWABLE (gtk_widget_get_window (parent)));
+	xid = gdk_x11_window_get_xid (gtk_widget_get_window (parent));
 
 	package = brasero_pk_new ();
 	cancel = g_cancellable_new ();
@@ -2328,6 +2336,7 @@ brasero_project_register_ui (BraseroProject *project, GtkUIManager *manager)
 {
 	GError *error = NULL;
 	GtkAction *action;
+	GtkWidget *toolbar;
 
 	/* menus */
 	project->priv->project_group = gtk_action_group_new ("ProjectActions1");
@@ -2345,7 +2354,11 @@ brasero_project_register_ui (BraseroProject *project, GtkUIManager *manager)
 		g_message ("building menus/toolbar failed: %s", error->message);
 		g_error_free (error);
 	}
-	
+
+	toolbar = gtk_ui_manager_get_widget (manager, "/Toolbar");
+	gtk_style_context_add_class (gtk_widget_get_style_context (toolbar),
+				     GTK_STYLE_CLASS_PRIMARY_TOOLBAR);
+
 	action = gtk_action_group_get_action (project->priv->project_group, "Save");
 	g_object_set (action,
 		      "short-label", _("_Save"), /* for toolbar buttons */
